@@ -11,9 +11,9 @@ use IO::Interactive qw(is_interactive);
 
 # put global variables alphabetically here
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-12-01'; # DATE
+our $DATE = '2021-12-09'; # DATE
 our $DIST = 'Perinci-CmdLine-Lite'; # DIST
-our $VERSION = '1.912'; # VERSION
+our $VERSION = '1.913'; # VERSION
 
 sub meta {
     return {
@@ -183,6 +183,12 @@ sub on_run {
         $r->{res}[0] = 555;
     }
 
+    $r->{res}[3]{title} //= join(
+        " ",
+        $self->cmdline->program_name,
+        @{ $r->{orig_argv} // \@ARGV },
+    );
+
     $r->{format} //= $r->{res}[3]{'cmdline.default_format'};
     $r->{format} //= $r->{meta}{'cmdline.default_format'};
     my $restore_orig_result;
@@ -262,7 +268,7 @@ Perinci::CmdLine::Plugin::Run::Normal - Normal run
 
 =head1 VERSION
 
-This document describes version 1.912 of Perinci::CmdLine::Plugin::Run::Normal (from Perl distribution Perinci-CmdLine-Lite), released on 2021-12-01.
+This document describes version 1.913 of Perinci::CmdLine::Plugin::Run::Normal (from Perl distribution Perinci-CmdLine-Lite), released on 2021-12-09.
 
 =for Pod::Coverage ^(.+)$
 
